<template>
  <div style="display: flex; flex-direction: column; align-items: center;">
    <div style="display: flex; flex-wrap: wrap; justify-content: center; margin-bottom: 20px">
      <div class=roomwrap v-for="(value, key) in bedMap" :key="key">
        <RoomBedSelect :title="key" :bedList="value" :curBed="curSel" @event-haveseat="haveSeat" @event-leaveseat="leaveSeat"/>
      </div>
      <div v-if="isEmptyOpeningBed">"工位没有开放"</div>
    </div>
    <div>
      <el-button @click="confirmCurSel">确认</el-button>
      <el-button @click="resetPage">重置</el-button>
    </div>
  </div>
</template>

<script setup lang="ts">
import {RoomBedSelect} from "@/components/RoomBedSelect"
import { RoomApi, RoomVO } from '@/api/ecg/room'
import { queueApi } from '@/api/ecg/queue'
import {useUserStore} from "@/store/modules/user";
import {ElMessage, ElMessageBox} from "element-plus";
import {isStringEmpty} from "@/utils/stringUtil";
import {cloneDeep} from "lodash-es";
const {  push } = useRouter()

defineOptions({ name: 'RoomLoginSelect' })

const route = useRoute();

const userStore = useUserStore()
const curUser = userStore.getUser

const isEmptyOpeningBed = ref<boolean>(true);
const bedMap = ref() // 列表的数据
const curSel = ref<RoomVO>({
  id: null,
  roomId: null,
  roomName: null,
  bedNo: null,
  status: null,
  docId: null,
  docName: null
})

/** 初始化 **/
onMounted(() => {
    getList()
})

const resetPage = () => {
    getList()
}

/** 查询列表 */
const getList = async () => {
  resetCurSel()

  const data = await RoomApi.getOpeningBedMap()
  console.info(data)
  bedMap.value = data;

  isEmptyOpeningBed.value = true
  for (const key in data) {
      isEmptyOpeningBed.value = false
      const roomVOArray = data[key] as RoomVO[];
      roomVOArray.forEach((roomVO) => {
          if (roomVO.docId === curUser.id) {
              curSel.value = roomVO
              return
          }
      } )
  }
}

const haveSeatConfirm = async (newRoomVO: RoomVO) => {
  if (newRoomVO !== curSel.value) {
    let data;
    if (curSel.value.docId !== null) {
      data = await queueApi.bedDoctorOff(curSel.value)
      if (data !== 0) {
        ElMessage({
          message: '内部错误!' + data,
          type: 'info',
          duration: 3000 // 自动关闭时间，默认为3000ms
        });
        return
      }
    }
    curSel.value.docId = null
    curSel.value.docName = null

    const tempRoomVO = cloneDeep(newRoomVO)
    tempRoomVO.docId = curUser.id
    tempRoomVO.docName = curUser.nickname
    data = await queueApi.bedDoctorOn(tempRoomVO)
    if (data !== 0) {
      ElMessage({
        message: '内部错误!' + data,
        type: 'info',
        duration: 3000 // 自动关闭时间，默认为3000ms
      });
      return
    }

    newRoomVO.docId = curUser.id
    newRoomVO.docName = curUser.nickname
    curSel.value = newRoomVO
    userStore.setRoomInfoAction(curSel.value)
  }

  if (isStringEmpty(route.redirectedFrom?.fullPath))
    push({ path: "/"})
  else if(route.redirectedFrom?.fullPath === "/roomselect" )
    push({ path: "/"})
  else
    push({ path: route.redirectedFrom?.fullPath})
}

const leaveSeatConfirm = async () => {
  if (curSel.value.docId !== null) {
      let data = await queueApi.bedDoctorOff(curSel.value)
      if (data !== 0) {
          ElMessage({
              message: '内部错误!' + data,
              type: 'info',
              duration: 3000 // 自动关闭时间，默认为3000ms
          });
          return
      }

    curSel.value.docId = null
    curSel.value.docName = null
  }

  userStore.clearRoomInfoAction()
}

const haveSeat = async (newRoomVO: RoomVO) => {
  ElMessageBox.confirm(
      '入座, 是否继续?',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }
  ).then(async () => {
    console.log('确认');
    haveSeatConfirm(newRoomVO)
  }).catch(() => {
    console.log('取消');
  });
}

const leaveSeat = (roomVO: RoomVO) => {
  ElMessageBox.confirm(
      '离座, 是否继续?',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }
  ).then(() => {
    console.log('确认');
    leaveSeatConfirm()
  }).catch(() => {
    console.log('取消');
  });
}

const confirmCurSel = () => {
  if (curSel.value.docId === null ) {
    ElMessage({
      message: '请先选择工作的位置!',
      type: 'info',
      duration: 3000 // 自动关闭时间，默认为3000ms
    });
    return
  }

  userStore.setRoomInfoAction(curSel.value)
  if (isStringEmpty(route.redirectedFrom?.fullPath))
    push({ path: "/"})
  else if(route.redirectedFrom?.fullPath === "/roomselect" )
    push({ path: "/"})
  else
    push({ path: route.redirectedFrom?.fullPath})
}

const resetCurSel = () => {
    curSel.value.id = null
    curSel.value.roomId = null
    curSel.value.roomName = null
    curSel.value.bedNo = null
    curSel.value.status = null
    curSel.value.docId = null
    curSel.value.docName = null
}

</script>

<style scoped lang="scss">
.roomwrap {
  margin-right: 20px;
}
</style>
